
/*

  Read a data file in the form generated by the propagator program,
  extracting a set of specified spinors.

*/

#include <stdio.h>
#include "datahdr.h"
#include "strmhdr.h"

#define S_SLICE 0
#define S_POINT 1

static char *usage        = "USAGE: inspect <state> <data> <sites...>\n" ;

void get_params (state, file1, nsites, sites, argc, argv)
char **state, **file1 ;
int  *nsites, **sites ;
int argc ;
char *argv [] ;
{
  int i ;

  if (argc < 3)
  {
    fprintf (stderr, usage) ;
    exit (1) ;
  }
  *state = argv [1] ;

  if (! strcmp (argv [2], "-"))
    *file1 = NULL ;
  else
    *file1 = argv [2] ;

  *nsites = argc - 3 ;
  *sites  = (int *) malloc (sizeof (int) * (*nsites)) ;
  for (i = 0; i < *nsites; i++)
    (*sites) [i] = atoi (argv [3 + i]) ;
}

void main (argc, argv)
int argc ;
char *argv [] ;
{
  char *state, *file1 ;
  int nsites, *sites ;
  DATA *datas, *data1 ;
  int   params [NUM_STT_PARAMS + NUM_DAT_PARAMS] ;
  float coeffs [NUM_STT_COEFFS + NUM_DAT_COEFFS] ;
  int l_time, l_space ;

  get_params  (&state, &file1, &nsites, &sites, argc, argv) ;
  fprintf (stderr, "searching for %d sites\n", nsites) ;

  datas = data_open_read (state) ;
  read_header     (datas) ;
  read_coeffs     (datas, coeffs) ;
  read_params     (datas, params) ;
  data_close_read (datas) ;

  l_time  = params [STT_L_T] ;
  l_space = params [STT_L_X] * params [STT_L_Y] * params [STT_L_Z] ;

  data1 = data_open_read (file1) ;
  read_header (data1) ;
  read_coeffs (data1, coeffs + NUM_STT_COEFFS) ;
  read_params (data1, params + NUM_STT_PARAMS) ;

  /*
  fprintf (stderr, "%d\n", params [NUM_STT_PARAMS + DAT_SC    ]) ;
  */
  fprintf (stderr, "%f\n", coeffs [NUM_STT_COEFFS + DAT_K_FERM]) ;
  fprintf (stderr, "\n") ;

  read_field_begin  (data1) ;
  print_site (data1, l_time, l_space, nsites, sites) ;

  data_close_read  (data1) ;
}

